@@ -916,6 +916,15 @@ class FormatJfs(FormatProcessGeneric):
         return self.get_label(), "-f", self.dev
 
 
+class FormatF2FS(FormatProcessGeneric):
+    format_util = "/usr/sbin/mkfs.f2fs"
+
+    def label(self):
+        return "-l", self._label
+
+    def param(self):
+        return self.get_label(), "-f", self.dev
+
 class FormatReiserfs(FormatProcessGeneric):
     format_util = "/sbin/mkfs.reiserfs"
 
@@ -994,6 +1003,7 @@ class PartitionDistributive(Distributive):
         'ext3': FormatExt3,
         'ext4': FormatExt4,
         'jfs': FormatJfs,
+        'f2fs': FormatF2FS,
         'reiserfs': FormatReiserfs,
         'btrfs': FormatBtrfs,
         'nilfs2': FormatNilfs2,
